@@ -1,14 +1,16 @@
 #!/bin/bash
 
-cd $(dirname $(realpath $0))
+set -euxo pipefail
+
+cd "$(dirname "$(realpath "$0")")"
 
 chmod 400 id_rsa
 rm -f known_host ssh_log
 
-if [ "$1" != "term" ]; then
+if [ $# -eq 0 ] || [ "$1" != "term" ]; then
     options="-nT"
 else
-    options="${@:2}"
+    options="${*:2}"
 fi
 
 sleep 4
@@ -17,6 +19,7 @@ for i in 1 2 3 4 5 6 7 8 9 10; do
     echo The $i try...
 
     sleep $i
+    # shellcheck disable=SC2086
     ssh test@localhost \
         -p 2435 \
         -i id_rsa \
@@ -40,5 +43,5 @@ for i in 1 2 3 4 5 6 7 8 9 10; do
 done
 
 echo Failed to start ssh
-cat *log
+cat -- *log
 exit 1
